@@ -9,7 +9,7 @@ import numpy as np
 import cv2 as cv
 import io
 from threading import Thread
-import keyboard
+#import keyboard
 import time
 
 num_vector = 7
@@ -258,15 +258,15 @@ class CogEnvDecoder:
         return [coll_time, cont_coll_time]
 
     def _thread_step(self):
-        quit = False
+        #quit = False
         #print('1')
         while True:
             self._env._env.step()
             time.sleep(0.015)
-            if keyboard.is_pressed('q'):
-                quit = True
-                self.close()
-                self._thread.join()
+            #if keyboard.is_pressed('q'):
+            #    quit = True
+            #    self.close()
+            #    self._thread.join()
 
 
 
